{% load theme_tags %} {% load news_tags %} {% load article_tags %} {% list_news as featured_news limit=TEMPLATE_NEWS_ARTICLES_FEATURED_LIMIT %} {% list_articles as featured_articles limit=TEMPLATE_NEWS_ARTICLES_FEATURED_LIMIT %}

### {% firstof TEMPLATE_NEWS_ARTICLES_FEATURED_NEWSTITLE "News" %}

{% if featured_news %} {% for news_item in featured_news %}

{{ news_item.body|striptags|truncatewords:30|safe }}

Read more {% endfor %} {% else %}

Tendenci supports great news updates for your members and website visitors. You can pull extra details from the latest news, while showing other news items to the side. {% if request.user.is_authenticated %}Add your first news item to take the place of these examples.{% endif %}

Read more {% endif %}

## {% firstof TEMPLATE_NEWS_ARTICLES_FEATURED_ARTICLESTITLE "News" %}

{% if featured_articles %} {% for art in featured_articles %}

{{ art.body|striptags|truncatewords:30|safe }}

Read more {% endfor %} {% else %}

Tendenci supports great article updates for your members and website visitors. You can pull extra details from the latest news, while showing other news items to the side. {% if request.user.is_authenticated %}Add your first article to take the place of these examples.{% endif %}

Read more {% endif %}
{% theme_setting setting_name %}